@@ -14,8 +14,9 @@
 #include "agendaview.h"
 #include "prefs.h"
 
-#include <Akonadi/Calendar/ETMCalendar>
-#include <Akonadi/Calendar/IncidenceChanger>
+#include <Akonadi/CalendarUtils>
+#include <Akonadi/ETMCalendar>
+#include <Akonadi/IncidenceChanger>
 #include <CalendarSupport/Utils>
 
 #include <KCalendarCore/Incidence>
@@ -38,21 +39,24 @@
 #include <QTimer>
 #include <QWheelEvent>
 
-#include <cmath> // for fabs()
+#include <chrono>
+#include <cmath>
+
+using namespace std::chrono_literals; // for fabs()
 
 using namespace EventViews;
 
 ///////////////////////////////////////////////////////////////////////////////
-class Q_DECL_HIDDEN MarcusBains::Private
+class EventViews::MarcusBainsPrivate
 {
 public:
-    Private(EventView *eventView, Agenda *agenda)
+    MarcusBainsPrivate(EventView *eventView, Agenda *agenda)
         : mEventView(eventView)
         , mAgenda(agenda)
     {
     }
 
-    int todayColumn() const;
+    Q_REQUIRED_RESULT int todayColumn() const;
 
 public:
     EventView *const mEventView;
@@ -63,7 +67,7 @@ public:
     int mOldTodayCol = -1;
 };
 
-int MarcusBains::Private::todayColumn() const
+int MarcusBainsPrivate::todayColumn() const
 {
     const QDate currentDate = QDate::currentDate();
 
@@ -81,7 +85,7 @@ int MarcusBains::Private::todayColumn() const
 
 MarcusBains::MarcusBains(EventView *eventView, Agenda *agenda)
     : QFrame(agenda)
-    , d(new Private(eventView, agenda))
+    , d(new MarcusBainsPrivate(eventView, agenda))
 {
     d->mTimeBox = new QLabel(d->mAgenda);
     d->mTimeBox->setAlignment(Qt::AlignRight | Qt::AlignBottom);
@@ -92,10 +96,7 @@ MarcusBains::MarcusBains(EventView *eventView, Agenda *agenda)
     d->mTimer->start(0);
 }
 
-MarcusBains::~MarcusBains()
-{
-    delete d;
-}
+MarcusBains::~MarcusBains() = default;
 
 void MarcusBains::updateLocation()
 {
@@ -173,7 +174,7 @@ void MarcusBains::updateLocationRecalc(bool recalculate)
     d->mTimeBox->raise();
 
     if (showSeconds || recalculate) {
-        d->mTimer->start(1000);
+        d->mTimer->start(1s);
     } else {
         d->mTimer->start(1000 * (60 - time.second()));
     }
@@ -181,10 +182,10 @@ void MarcusBains::updateLocationRecalc(bool recalculate)
 
 ////////////////////////////////////////////////////////////////////////////
 
-class Q_DECL_HIDDEN Agenda::Private
+class EventViews::AgendaPrivate
 {
 public:
-    Private(AgendaView *agendaView, QScrollArea *scrollArea, int columns, int rows, int rowSize, bool isInteractive)
+    AgendaPrivate(AgendaView *agendaView, QScrollArea *scrollArea, int columns, int rows, int rowSize, bool isInteractive)
         : mAgendaView(agendaView)
         , mScrollArea(scrollArea)
         , mAllDayMode(false)
@@ -203,7 +204,7 @@ public:
         , mWorkingHoursYTop(0)
         , mWorkingHoursYBottom(0)
         , mHasSelection(false)
-        , mSelectedId(-1)
+        , mSelectedId(QChar(-1))
         , mMarcusBains(nullptr)
         , mActionType(Agenda::NOP)
         , mItemMoved(false)
@@ -263,11 +264,11 @@ public:
     QTimer mScrollUpTimer;
     QTimer mScrollDownTimer;
 
-    // Cells to store Move and Resize coordiantes while performing the action
+    // Cells to store Move and Resize coordinates while performing the action
     QPoint mStartCell;
     QPoint mEndCell;
 
-    // Working Hour coordiantes
+    // Working Hour coordinates
     bool mWorkingHoursEnable;
     QVector<bool> *mHolidayMask = nullptr;
     int mWorkingHoursYTop;
@@ -298,7 +299,7 @@ public:
     // The Marcus Bains Line widget.
     MarcusBains *mMarcusBains = nullptr;
 
-    MouseActionType mActionType;
+    Agenda::MouseActionType mActionType;
 
     bool mItemMoved;
 
@@ -320,7 +321,7 @@ public:
 */
 Agenda::Agenda(AgendaView *agendaView, QScrollArea *scrollArea, int columns, int rows, int rowSize, bool isInteractive)
     : QWidget(scrollArea)
-    , d(new Private(agendaView, scrollArea, columns, rows, rowSize, isInteractive))
+    , d(new AgendaPrivate(agendaView, scrollArea, columns, rows, rowSize, isInteractive))
 {
     setMouseTracking(true);
 
@@ -333,7 +334,7 @@ Agenda::Agenda(AgendaView *agendaView, QScrollArea *scrollArea, int columns, int
 */
 Agenda::Agenda(AgendaView *agendaView, QScrollArea *scrollArea, int columns, bool isInteractive)
     : QWidget(scrollArea)
-    , d(new Private(agendaView, scrollArea, columns, 1, 24, isInteractive))
+    , d(new AgendaPrivate(agendaView, scrollArea, columns, 1, 24, isInteractive))
 {
     d->mAllDayMode = true;
 
@@ -343,7 +344,6 @@ Agenda::Agenda(AgendaView *agendaView, QScrollArea *scrollArea, int columns, boo
 Agenda::~Agenda()
 {
     delete d->mMarcusBains;
-    delete d;
 }
 
 KCalendarCore::Incidence::Ptr Agenda::selectedIncidence() const
@@ -407,7 +407,7 @@ void Agenda::init()
     d->mItemMoved = false;
 
     d->mSelectedItem = nullptr;
-    d->mSelectedId = -1;
+    d->mSelectedId = QChar(-1);
 
     setAcceptDrops(true);
     installEventFilter(this);
@@ -420,7 +420,7 @@ void Agenda::init()
 
     calculateWorkingHours();
 
-    connect(verticalScrollBar(), SIGNAL(valueChanged(int)), SLOT(checkScrollBoundaries(int)));
+    connect(verticalScrollBar(), &QScrollBar::valueChanged, this, qOverload<int>(&Agenda::checkScrollBoundaries));
 
     // Create the Marcus Bains line.
     if (d->mAllDayMode) {
@@ -594,7 +594,6 @@ bool Agenda::eventFilter_drag(QObject *obj, QDropEvent *de)
             Q_EMIT droppedIncidences(incidences, gridPosition, d->mAllDayMode);
         }
         return true;
-        break;
     }
 
     case QEvent::DragResponse:
@@ -1148,8 +1147,8 @@ void Agenda::endItemAction()
 
     d->mItemMoved = d->mItemMoved && !(d->mStartCell.x() == d->mEndCell.x() && d->mStartCell.y() == d->mEndCell.y());
 
-    bool addIncidence = false;
     if (d->mItemMoved) {
+        bool addIncidence = false;
         bool modify = false;
 
         // get the main event and not the exception
@@ -1327,7 +1326,8 @@ void Agenda::setNoActionCursor(const AgendaItem::QPtr &moveItem, QPoint pos)
  */
 double Agenda::calcSubCellWidth(const AgendaItem::QPtr &item)
 {
-    QPoint pt, pt1;
+    QPoint pt;
+    QPoint pt1;
     pt = gridToContents(QPoint(item->cellXLeft(), item->cellYTop()));
     pt1 = gridToContents(QPoint(item->cellXLeft(), item->cellYTop()) + QPoint(1, 1));
     pt1 -= pt;
@@ -1371,7 +1371,10 @@ void Agenda::placeAgendaItem(const AgendaItem::QPtr &item, double subCellWidth)
     if (subCellWidth < 0) {
         delta = -delta;
     }
-    int height, width, xpos, ypos;
+    int height;
+    int width;
+    int xpos;
+    int ypos;
     if (d->mAllDayMode) {
         width = pt1.x() - pt.x();
         height = int(subCellPos + subCellWidth + delta) - int(subCellPos);
@@ -1572,7 +1575,8 @@ void Agenda::drawContents(QPainter *p, int cx, int cy, int cw, int ch)
 
     // draw selection
     if (d->mHasSelection && d->mAgendaView->dateRangeSelectionEnabled()) {
-        QPoint pt, pt1;
+        QPoint pt;
+        QPoint pt1;
         QColor highlightColor;
         if (!d->preferences()->useSystemColor()) {
             highlightColor = d->preferences()->agendaGridHighlightColor();
@@ -1760,11 +1764,11 @@ AgendaItem::QPtr Agenda::insertItem(const KCalendarCore::Incidence::Ptr &inciden
 
     AgendaItem::QPtr agendaItem = createAgendaItem(incidence, itemPos, itemCount, recurrenceId, isSelected);
     if (!agendaItem) {
-        return AgendaItem::QPtr();
+        return {};
     }
 
     if (YTop >= d->mRows) {
-        YBottom -= YTop - (d->mRows - 1);  // Slide the item up into view.
+        YBottom -= YTop - (d->mRows - 1); // Slide the item up into view.
         YTop = d->mRows - 1;
     }
     if (YBottom <= YTop) {
@@ -1805,7 +1809,7 @@ AgendaItem::QPtr Agenda::insertAllDayItem(const KCalendarCore::Incidence::Ptr &i
 
     AgendaItem::QPtr agendaItem = createAgendaItem(incidence, 1, 1, recurrenceId, isSelected);
     if (!agendaItem) {
-        return AgendaItem::QPtr();
+        return {};
     }
 
     agendaItem->setCellXY(XBegin, 0, 0);
@@ -1833,7 +1837,7 @@ Agenda::createAgendaItem(const KCalendarCore::Incidence::Ptr &incidence, int ite
 {
     if (!incidence) {
         qCWarning(CALENDARVIEW_LOG) << "Agenda::createAgendaItem() item is invalid.";
-        return AgendaItem::QPtr();
+        return {};
     }
 
     AgendaItem::QPtr agendaItem = new AgendaItem(d->mAgendaView, d->mCalendar, incidence, itemPos, itemCount, recurrenceId, isSelected, this);
@@ -1862,7 +1866,9 @@ void Agenda::insertMultiItem(const KCalendarCore::Incidence::Ptr &event,
     }
 
     d->mActionType = NOP;
-    int cellX, cellYTop, cellYBottom;
+    int cellX;
+    int cellYTop;
+    int cellYBottom;
     QString newtext;
     int width = XEnd - XBegin + 1;
     int count = 0;
@@ -1899,7 +1905,8 @@ void Agenda::insertMultiItem(const KCalendarCore::Incidence::Ptr &event,
     if (it != e) { // .first asserts if the list is empty
         AgendaItem::QPtr first = multiItems.first();
         AgendaItem::QPtr last = multiItems.last();
-        AgendaItem::QPtr prev = nullptr, next = nullptr;
+        AgendaItem::QPtr prev = nullptr;
+        AgendaItem::QPtr next = nullptr;
 
         while (it != e) {
             AgendaItem::QPtr item = *it;
@@ -2227,7 +2234,7 @@ void Agenda::selectIncidenceByUid(const QString &uid)
 
 void Agenda::selectItem(const Akonadi::Item &item)
 {
-    selectIncidenceByUid(CalendarSupport::incidence(item)->uid());
+    selectIncidenceByUid(Akonadi::CalendarUtils::incidence(item)->uid());
 }
 
 // This function seems never be called.
@@ -2332,9 +2339,7 @@ AgendaScrollArea::AgendaScrollArea(bool isAllDay, AgendaView *agendaView, bool i
     mAgenda->setStartTime(agendaView->preferences()->dayBegins().time());
 }
 
-AgendaScrollArea::~AgendaScrollArea()
-{
-}
+AgendaScrollArea::~AgendaScrollArea() = default;
 
 Agenda *AgendaScrollArea::agenda() const
 {
