@@ -15,13 +15,15 @@
 #include "eventviews_export.h"
 #include "viewcalendar.h"
 
-#include <Item>
+#include <Akonadi/Item>
 
 #include <KCalendarCore/Todo>
 
 #include <QFrame>
 #include <QScrollArea>
 
+#include <memory>
+
 namespace Akonadi
 {
 class IncidenceChanger;
@@ -33,6 +35,8 @@ class Agenda;
 class AgendaItem;
 class AgendaView;
 
+class MarcusBainsPrivate;
+
 class MarcusBains : public QFrame
 {
     Q_OBJECT
@@ -45,10 +49,11 @@ public Q_SLOTS:
     void updateLocation();
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<MarcusBainsPrivate> const d;
 };
 
+class AgendaPrivate;
+
 class EVENTVIEWS_EXPORT Agenda : public QWidget
 {
     Q_OBJECT
@@ -317,8 +322,8 @@ private:
     void marcus_bains();
 
 private:
-    class Private;
-    Private *const d;
+    friend class AgendaPrivate;
+    std::unique_ptr<AgendaPrivate> const d;
 };
 
 class AgendaScrollArea : public QScrollArea
@@ -326,7 +331,7 @@ class AgendaScrollArea : public QScrollArea
     Q_OBJECT
 public:
     AgendaScrollArea(bool allDay, AgendaView *agendaView, bool isInteractive, QWidget *parent);
-    ~AgendaScrollArea();
+    ~AgendaScrollArea() override;
 
     Agenda *agenda() const;
 
@@ -334,4 +339,3 @@ private:
     Agenda *mAgenda = nullptr;
 };
 }
-
