@@ -20,8 +20,9 @@
 
 #include "calendarview_debug.h"
 
-#include <Akonadi/Calendar/ETMCalendar>
-#include <Akonadi/Calendar/IncidenceChanger>
+#include <Akonadi/CalendarUtils>
+#include <Akonadi/ETMCalendar>
+#include <Akonadi/IncidenceChanger>
 #include <CalendarSupport/CollectionSelection>
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
@@ -32,7 +33,7 @@
 
 #include <KIconLoader> // for SmallIcon()
 #include <KMessageBox>
-#include <KServiceTypeTrader>
+#include <KPluginFactory>
 #include <KSqueezedTextLabel>
 
 #include <KLocalizedString>
@@ -59,7 +60,7 @@ enum {
 };
 
 // Layout which places the widgets in equally sized columns,
-// matching the calculcation of the columns in the agenda.
+// matching the calculation of the columns in the agenda.
 class AgendaHeaderLayout : public QLayout
 {
 public:
@@ -265,8 +266,7 @@ void AgendaHeader::setAgenda(Agenda *agenda)
 void AgendaHeader::updateMargins()
 {
     const int frameWidth = mAgenda ? mAgenda->scrollArea()->frameWidth() : 0;
-    const int scrollBarWidth = (mIsSideBySide || !mAgenda) ? 0 : mAgenda->verticalScrollBar()->width();
-
+    const int scrollBarWidth = (mIsSideBySide || !mAgenda || !mAgenda->verticalScrollBar()->isVisible()) ? 0 : mAgenda->verticalScrollBar()->width();
     const bool isLTR = (layoutDirection() == Qt::LeftToRight);
     const int leftSpacing = SPACING + frameWidth;
     const int rightSpacing = scrollBarWidth + frameWidth;
@@ -422,33 +422,15 @@ void AgendaHeader::loadDecorations(const QStringList &decorations, const QString
 
 CalendarDecoration::Decoration *AgendaHeader::loadCalendarDecoration(const QString &name)
 {
-    const QString type = CalendarSupport::Plugin::serviceType();
-    const int version = CalendarSupport::Plugin::interfaceVersion();
+    auto result = KPluginFactory::instantiatePlugin<CalendarDecoration::Decoration>(
+        KPluginMetaData(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/korganizer/") + name));
 
-    QString constraint;
-    if (version >= 0) {
-        constraint = QStringLiteral("[X-KDE-PluginInterfaceVersion] == %1").arg(QString::number(version));
+    if (result) {
+        return result.plugin;
+    } else {
+        qCDebug(CALENDARVIEW_LOG) << "Factory creation failed" << result.errorString;
+        return nullptr;
     }
-
-    KService::List list = KServiceTypeTrader::self()->query(type, constraint);
-
-    KService::List::ConstIterator it;
-    for (it = list.constBegin(); it != list.constEnd(); ++it) {
-        if ((*it)->desktopEntryName() == name) {
-            KService::Ptr service = *it;
-            KPluginLoader loader(*service);
-
-            auto factory = loader.factory();
-            if (!factory) {
-                qCDebug(CALENDARVIEW_LOG) << "Factory creation failed";
-                return nullptr;
-            }
-
-            return factory->create<CalendarDecoration::Decoration>();
-        }
-    }
-
-    return nullptr;
 }
 
 class EventViews::EventIndicatorPrivate
@@ -571,6 +553,7 @@ public:
     AgendaHeader *mTopDayLabelsFrame = nullptr;
     AgendaHeader *mBottomDayLabelsFrame = nullptr;
     QWidget *mAllDayFrame = nullptr;
+    QSpacerItem *mAllDayRightSpacer = nullptr;
     QWidget *mTimeBarHeaderFrame = nullptr;
     QSplitter *mSplitterAgenda = nullptr;
     QList<QLabel *> mTimeBarHeaders;
@@ -642,6 +625,8 @@ public:
      */
     bool mightBeVisible(const KCalendarCore::Incidence::Ptr &incidence) const;
 
+    void updateAllDayRightSpacer();
+
 protected:
     /* reimplemented from KCalendarCore::Calendar::CalendarObserver */
     void calendarIncidenceAdded(const KCalendarCore::Incidence::Ptr &incidence) override;
@@ -1064,6 +1049,23 @@ void AgendaViewPrivate::insertIncidence(const KCalendarCore::Incidence::Ptr &inc
     }
 }
 
+void AgendaViewPrivate::updateAllDayRightSpacer()
+{
+    if (!mAllDayRightSpacer) {
+        return;
+    }
+
+    // Make the all-day and normal agendas line up with each other
+    auto verticalAgendaScrollBar = mAgenda->verticalScrollBar();
+    int margin = verticalAgendaScrollBar->isVisible() ? verticalAgendaScrollBar->width() : 0;
+    if (q->style()->styleHint(QStyle::SH_ScrollView_FrameOnlyAroundContents)) {
+        // Needed for some styles. Oxygen needs it, Plastique does not.
+        margin -= mAgenda->scrollArea()->frameWidth();
+    }
+    mAllDayRightSpacer->changeSize(margin, 0, QSizePolicy::Fixed);
+    mAllDayFrame->layout()->invalidate(); // needed to pick up change of space size
+}
+
 ////////////////////////////////////////////////////////////////////////////
 
 AgendaView::AgendaView(QDate start, QDate end, bool isInteractive, bool isSideBySide, QWidget *parent)
@@ -1127,6 +1129,7 @@ void AgendaView::init(QDate start, QDate end)
     // Create agenda
     auto scrollArea = new AgendaScrollArea(false, this, d->mIsInteractive, agendaFrame);
     d->mAgenda = scrollArea->agenda();
+    d->mAgenda->verticalScrollBar()->installEventFilter(this);
 
     // Create event indicator bars
     d->mEventIndicatorTop = new EventIndicator(EventIndicator::Top, scrollArea->viewport());
@@ -1165,13 +1168,8 @@ void AgendaView::init(QDate start, QDate end)
     d->mBottomDayLabelsFrame->setAgenda(d->mAgenda);
 
     if (!d->mIsSideBySide) {
-        /* Make the all-day and normal agendas line up with each other */
-        int margin = style()->pixelMetric(QStyle::PM_ScrollBarExtent);
-        if (style()->styleHint(QStyle::SH_ScrollView_FrameOnlyAroundContents)) {
-            // Needed for some styles. Oxygen needs it, Plastique does not.
-            margin -= scrollArea->frameWidth();
-        }
-        d->mAllDayFrame->layout()->addItem(new QSpacerItem(margin, 0));
+        d->mAllDayRightSpacer = new QSpacerItem(0, 0);
+        d->mAllDayFrame->layout()->addItem(d->mAllDayRightSpacer);
     }
 
     updateTimeBarWidth();
@@ -1211,6 +1209,17 @@ void AgendaView::showEvent(QShowEvent *showEvent)
     // agenda scrollbar width only set now, so redo margin calculation
     d->mTopDayLabelsFrame->updateMargins();
     d->mBottomDayLabelsFrame->updateMargins();
+    d->updateAllDayRightSpacer();
+}
+
+bool AgendaView::eventFilter(QObject *object, QEvent *event)
+{
+    if ((object == d->mAgenda->verticalScrollBar()) && ((event->type() == QEvent::Show) || (event->type() == QEvent::Hide))) {
+        d->mTopDayLabelsFrame->updateMargins();
+        d->mBottomDayLabelsFrame->updateMargins();
+        d->updateAllDayRightSpacer();
+    }
+    return false;
 }
 
 KCalendarCore::Calendar::Ptr AgendaView::calendar2(const KCalendarCore::Incidence::Ptr &incidence) const
@@ -1250,7 +1259,7 @@ void AgendaView::connectAgenda(Agenda *agenda, Agenda *otherAgenda)
 
     agenda->setCalendar(d->mViewCalendar);
 
-    connect(agenda, SIGNAL(newEventSignal()), SIGNAL(newEventSignal()));
+    connect(agenda, &Agenda::newEventSignal, this, qOverload<>(&EventView::newEventSignal));
 
     connect(agenda, &Agenda::newStartSelectSignal, otherAgenda, &Agenda::clearSelection);
     connect(agenda, &Agenda::newStartSelectSignal, this, &AgendaView::timeSpanSelectionChanged);
@@ -1780,7 +1789,7 @@ void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence, Akonadi::
         Akonadi::Collection collection = calendar()->collection(collectionId);
         result = changer()->createIncidence(incidence, collection, this) != -1;
     } else {
-        KCalendarCore::Incidence::Ptr oldIncidence(CalendarSupport::incidence(aitem));
+        KCalendarCore::Incidence::Ptr oldIncidence(Akonadi::CalendarUtils::incidence(aitem));
         aitem.setPayload<KCalendarCore::Incidence::Ptr>(incidence);
         result = changer()->modifyIncidence(aitem, oldIncidence, this) != -1;
     }
@@ -1859,7 +1868,7 @@ void AgendaView::showIncidences(const Akonadi::Item::List &incidences, const QDa
     bool wehaveall = true;
     if (filter) {
         for (const Akonadi::Item &aitem : incidences) {
-            if (!(wehaveall = filter->filterIncidence(CalendarSupport::incidence(aitem)))) {
+            if (!(wehaveall = filter->filterIncidence(Akonadi::CalendarUtils::incidence(aitem)))) {
                 break;
             }
         }
@@ -1869,15 +1878,15 @@ void AgendaView::showIncidences(const Akonadi::Item::List &incidences, const QDa
         calendar()->setFilter(nullptr);
     }
 
-    QDateTime start = CalendarSupport::incidence(incidences.first())->dtStart().toLocalTime();
-    QDateTime end = CalendarSupport::incidence(incidences.first())->dateTime(KCalendarCore::Incidence::RoleEnd).toLocalTime();
+    QDateTime start = Akonadi::CalendarUtils::incidence(incidences.first())->dtStart().toLocalTime();
+    QDateTime end = Akonadi::CalendarUtils::incidence(incidences.first())->dateTime(KCalendarCore::Incidence::RoleEnd).toLocalTime();
     Akonadi::Item first = incidences.first();
     for (const Akonadi::Item &aitem : incidences) {
-        if (CalendarSupport::incidence(aitem)->dtStart().toLocalTime() < start) {
+        if (Akonadi::CalendarUtils::incidence(aitem)->dtStart().toLocalTime() < start) {
             first = aitem;
         }
-        start = qMin(start, CalendarSupport::incidence(aitem)->dtStart().toLocalTime());
-        end = qMax(start, CalendarSupport::incidence(aitem)->dateTime(KCalendarCore::Incidence::RoleEnd).toLocalTime());
+        start = qMin(start, Akonadi::CalendarUtils::incidence(aitem)->dtStart().toLocalTime());
+        end = qMax(start, Akonadi::CalendarUtils::incidence(aitem)->dateTime(KCalendarCore::Incidence::RoleEnd).toLocalTime());
     }
 
     end.toTimeZone(start.timeZone()); // allow direct comparison of dates
@@ -2124,11 +2133,11 @@ void AgendaView::slotIncidencesDropped(const QList<QUrl> &items, const QPoint &g
     KDateTime newTime(day, time, preferences()->timeSpec());
     newTime.setDateOnly(allDay);
 
-    Todo::Ptr todo = CalendarSupport::todo(todoItem);
+    Todo::Ptr todo = Akonadi::CalendarUtils4::todo(todoItem);
     if (todo && dynamic_cast<Akonadi::ETMCalendar *>(calendar())) {
         const Akonadi::Item existingTodoItem = calendar()->itemForIncidence(calendar()->todo(todo->uid()));
 
-        if (Todo::Ptr existingTodo = CalendarSupport::todo(existingTodoItem)) {
+        if (Todo::Ptr existingTodo = Akonadi::CalendarUtils::todo(existingTodoItem)) {
             qCDebug(CALENDARVIEW_LOG) << "Drop existing Todo";
             Todo::Ptr oldTodo(existingTodo->clone());
             if (changer()) {
@@ -2281,7 +2290,7 @@ void AgendaView::writeSettings(KConfig *config)
 QVector<bool> AgendaView::busyDayMask() const
 {
     if (d->mSelectedDates.isEmpty() || !d->mSelectedDates[0].isValid()) {
-        return QVector<bool>();
+        return {};
     }
 
     QVector<bool> busyDayMask;
