@@ -5,17 +5,20 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef EVENTVIEWS_LISTVIEW_H
-#define EVENTVIEWS_LISTVIEW_H
+#pragma once
 
 #include "eventview.h"
 
+#include <memory>
+
 class KConfig;
 
 class QModelIndex;
 
 namespace EventViews
 {
+class ListViewPrivate;
+
 /**
   This class provides a multi-column list view of events.  It can
   display events from one particular day or several days, it doesn't
@@ -39,9 +42,30 @@ public:
     // Shows all incidences of the calendar
     void showAll();
 
+    /**
+     * Read settings from the "ListView Layout" group of the configuration.
+     * @deprecated Use readSettings with a specific KConfigGroup.
+     */
     void readSettings(KConfig *config);
+
+    /**
+     * Read settings from the given configuration group.
+     * @since 5.18.1
+     */
+    void readSettings(const KConfigGroup &cfgGroup);
+
+    /**
+     * Write settings to the "ListView Layout" group of the configuration.
+     * @deprecated Use writeSettings with a specific KConfigGroup.
+     */
     void writeSettings(KConfig *config);
 
+    /**
+     * Write settings to the given configuration group.
+     * @since 5.18.1
+     */
+    void writeSettings(KConfigGroup &cfgGroup);
+
     void clear();
     QSize sizeHint() const override;
 
@@ -69,9 +93,8 @@ protected Q_SLOTS:
     void processSelectionChange();
 
 private:
-    class Private;
-    Private *const d;
+    void slotSortIndicatorChanged(int logicalIndex, Qt::SortOrder order);
+
+    std::unique_ptr<ListViewPrivate> const d;
 };
 }
-
-#endif
