@@ -12,6 +12,7 @@
 #include "prefs.h"
 #include "prefs_base.h" // Ugly, but needed for the Enums
 
+#include <Akonadi/CalendarUtils>
 #include <Akonadi/IncidenceChanger>
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
@@ -483,7 +484,10 @@ QString IncidenceMonthItem::text(bool end) const
 
 QString IncidenceMonthItem::toolTipText(const QDate &date) const
 {
-    return KCalUtils::IncidenceFormatter::toolTipStr(CalendarSupport::displayName(mCalendar.data(), akonadiItem().parentCollection()), mIncidence, date, true);
+    return KCalUtils::IncidenceFormatter::toolTipStr(Akonadi::CalendarUtils::displayName(mCalendar.data(), akonadiItem().parentCollection()),
+                                                     mIncidence,
+                                                     date,
+                                                     true);
 }
 
 QVector<QPixmap> IncidenceMonthItem::icons() const
@@ -575,7 +579,7 @@ QColor IncidenceMonthItem::bgColor() const
     const auto &prefs = monthScene()->monthView()->preferences();
 
     if (!prefs->todosUseCategoryColors() && mIsTodo) {
-        Todo::Ptr todo = CalendarSupport::todo(akonadiItem());
+        Todo::Ptr todo = Akonadi::CalendarUtils::todo(akonadiItem());
         Q_ASSERT(todo);
         if (todo) {
             // this is dtDue if there's no dtRecurrence
