@@ -8,7 +8,10 @@
 
 #include "whatsnextview.h"
 
-#include <Akonadi/Calendar/ETMCalendar>
+#include <kcalendarcore_version.h>
+
+#include <Akonadi/CalendarUtils>
+#include <Akonadi/ETMCalendar>
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 
@@ -17,9 +20,15 @@
 #include <QBoxLayout>
 
 using namespace EventViews;
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 void WhatsNextTextBrowser::setSource(const QUrl &name)
+#else
+void WhatsNextTextBrowser::doSetSource(const QUrl &name, QTextDocument::ResourceType type)
+#endif
 {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    Q_UNUSED(type);
+#endif
     const QString uri = name.toString();
     if (uri.startsWith(QLatin1String("event:"))) {
         Q_EMIT showIncidence(uri);
@@ -41,9 +50,7 @@ WhatsNextView::WhatsNextView(QWidget *parent)
     topLayout->addWidget(mView);
 }
 
-WhatsNextView::~WhatsNextView()
-{
-}
+WhatsNextView::~WhatsNextView() = default;
 
 int WhatsNextView::currentDateCount() const
 {
@@ -86,8 +93,12 @@ void WhatsNextView::updateView()
 
     KCalendarCore::Event::List events;
     events = calendar()->events(mStartDate, mEndDate, QTimeZone::systemTimeZone(), false);
-    events = calendar()->sortEvents(events, KCalendarCore::EventSortStartDate, KCalendarCore::SortDirectionAscending);
 
+#if KCALENDARCORE_VERSION < QT_VERSION_CHECK(5, 95, 0)
+    events = calendar()->sortEvents(events, KCalendarCore::EventSortStartDate, KCalendarCore::SortDirectionAscending);
+#else
+    events = calendar()->sortEvents(std::move(events), KCalendarCore::EventSortStartDate, KCalendarCore::SortDirectionAscending);
+#endif
     if (!events.isEmpty()) {
         mText += QLatin1String("<p></p>");
         kil->loadIcon(QStringLiteral("view-calendar-day"), KIconLoader::NoGroup, 22, KIconLoader::DefaultState, QStringList(), &ipath);
@@ -96,7 +107,7 @@ void WhatsNextView::updateView()
         mText += QLatin1String(R"(" width="22" height="22">)");
         mText += i18n("Events:") + QLatin1String("</h2>\n");
         mText += QLatin1String("<table>\n");
-        for (const KCalendarCore::Event::Ptr &ev : qAsConst(events)) {
+        for (const KCalendarCore::Event::Ptr &ev : std::as_const(events)) {
             if (!ev->recurs()) {
                 appendEvent(ev);
             } else {
@@ -131,7 +142,7 @@ void WhatsNextView::updateView()
     KCalendarCore::Todo::List todos = calendar()->todos(KCalendarCore::TodoSortDueDate, KCalendarCore::SortDirectionAscending);
     if (!todos.isEmpty()) {
         bool taskHeaderWasCreated = false;
-        for (const KCalendarCore::Todo::Ptr &todo : qAsConst(todos)) {
+        for (const KCalendarCore::Todo::Ptr &todo : std::as_const(todos)) {
             if (!todo->isCompleted() && todo->hasDueDate() && todo->dtDue().date() <= mEndDate) {
                 if (!taskHeaderWasCreated) {
                     createTaskRow(kil);
@@ -143,7 +154,7 @@ void WhatsNextView::updateView()
         bool gotone = false;
         int priority = 1;
         while (!gotone && priority <= 9) {
-            for (const KCalendarCore::Todo::Ptr &todo : qAsConst(todos)) {
+            for (const KCalendarCore::Todo::Ptr &todo : std::as_const(todos)) {
                 if (!todo->isCompleted() && (todo->priority() == priority)) {
                     if (!taskHeaderWasCreated) {
                         createTaskRow(kil);
@@ -163,7 +174,7 @@ void WhatsNextView::updateView()
     QStringList myEmails(CalendarSupport::KCalPrefs::instance()->allEmails());
     int replies = 0;
     events = calendar()->events(QDate::currentDate(), QDate(2975, 12, 6), QTimeZone::systemTimeZone());
-    for (const KCalendarCore::Event::Ptr &ev : qAsConst(events)) {
+    for (const KCalendarCore::Event::Ptr &ev : std::as_const(events)) {
         KCalendarCore::Attendee me = ev->attendeeByMails(myEmails);
         if (!me.isNull()) {
             if (me.status() == KCalendarCore::Attendee::NeedsAction && me.RSVP()) {
@@ -182,7 +193,7 @@ void WhatsNextView::updateView()
         }
     }
     todos = calendar()->todos();
-    for (const KCalendarCore::Todo::Ptr &to : qAsConst(todos)) {
+    for (const KCalendarCore::Todo::Ptr &to : std::as_const(todos)) {
         KCalendarCore::Attendee me = to->attendeeByMails(myEmails);
         if (!me.isNull()) {
             if (me.status() == KCalendarCore::Attendee::NeedsAction && me.RSVP()) {
@@ -285,7 +296,7 @@ void WhatsNextView::appendTodo(const KCalendarCore::Incidence::Ptr &incidence)
     mText += incidence->summary();
     mText += QLatin1String("</a>");
 
-    if (const KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(aitem)) {
+    if (const KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(aitem)) {
         if (todo->hasDueDate()) {
             mText += i18nc("to-do due date", "  (Due: %1)", KCalUtils::IncidenceFormatter::dateTimeToString(todo->dtDue(), todo->allDay()));
         }
